@@ -1,9 +1,19 @@
 from restless.util import FormData
 from pydantic import BaseModel
+from enum import Enum
+from typing import ClassVar
 
 
 class StringParameter(str):
-    pass
+    ENUM: Enum = None
+
+    @classmethod
+    def enum(cls, enum: Enum) -> ClassVar:
+        return type(cls.__name__, (cls,), {'ENUM': enum})
+
+    @classmethod
+    def enum_keys(cls):
+        return [k.strip('_') for k in cls.ENUM.__members__]
 
 
 class PathParameter(StringParameter):
